summaryrefslogtreecommitdiffstats
path: root/kalarm/kalarmapp.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /kalarm/kalarmapp.h
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/kalarmapp.h')
-rw-r--r--kalarm/kalarmapp.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kalarm/kalarmapp.h b/kalarm/kalarmapp.h
index 0aa81b1b..6653e810 100644
--- a/kalarm/kalarmapp.h
+++ b/kalarm/kalarmapp.h
@@ -62,7 +62,7 @@ class KAlarmApp : public KUniqueApplication
bool restoreSession();
bool sessionClosingDown() const { return mSessionClosingDown; }
void quitIf() { quitIf(0); }
- void doQuit(TQWidget* tqparent);
+ void doQuit(TQWidget* parent);
static void displayFatalError(const TQString& message);
void addWindow(TrayWindow* w) { mTrayWindow = w; }
void removeWindow(TrayWindow*);
@@ -77,7 +77,7 @@ class KAlarmApp : public KUniqueApplication
void alarmShowing(KAEvent&, KAAlarm::Type, const DateTime&);
void alarmCompleted(const KAEvent&);
bool deleteEvent(const TQString& eventID) { return handleEvent(eventID, EVENT_CANCEL); }
- void commandMessage(ShellProcess*, TQWidget* tqparent);
+ void commandMessage(ShellProcess*, TQWidget* parent);
// Methods called indirectly by the DCOP interface
bool scheduleEvent(KAEvent::Action, const TQString& text, const TQDateTime&,
int lateCancel, int flags, const TQColor& bg, const TQColor& fg,
@@ -160,9 +160,9 @@ class KAlarmApp : public KUniqueApplication
static int mFatalError; // a fatal error has occurred - just wait to exit
static TQString mFatalMessage; // fatal error message to output
bool mInitialised; // initialisation complete: ready to handle DCOP calls
- DcopHandler* mDcopHandler; // the tqparent of the main DCOP receiver object
+ DcopHandler* mDcopHandler; // the parent of the main DCOP receiver object
#ifdef OLD_DCOP
- DcopHandlerOld* mDcopHandlerOld; // the tqparent of the old main DCOP receiver object
+ DcopHandlerOld* mDcopHandlerOld; // the parent of the old main DCOP receiver object
#endif
TrayWindow* mTrayWindow; // active system tray icon
TQTime mStartOfDay; // start-of-day time currently in use